__author__ = "Paulo Antunes"
__copyright__ = "Copyright 2018, XTCryptoSignals"
__credits__ = [
    "Paulo Antunes",
]
__license__ = "GPL"
__maintainer__ = "Paulo Antunes"
__email__ = "pjmlantunes@gmail.com"


# Add the following Personal Exchange keys in order to be able to Trade

BINANCE_API_KEY = ""
BINANCE_API_SECRET = ""

KUCOIN_API_KEY = ""
KUCOIN_API_SECRET = ""
KUCOIN_API_PASSPHRASE = ""

IDEX_API_KEY = ""
IDEX_ADDRESS = ""
IDEX_PRIVATE_KEY = ""
